<?php
//
// Chapter 6, pg. 180-181  
//

require_once "PHPUnit/Framework/TestCase.php";

// WebAuthCase is an abstract class which just sets up the
// url for testing but runs no actual tests.
class WebAuthTestCase extends PHPUnit_Framework_TestCase{
  public $curl_handle;
  public $url;
  function __construct($name) {
    parent::__construct($name);
  }
  function setUp() {
    // initialize curl
    $this->curl_handle = curl_init();
    // set curl to return the response back to us after curl_exec
    curl_setopt($this->curl_handle, CURLOPT_RETURNTRANSFER, 1);
    // set the url
    $this->url = "http://devel.omniti.com/auth.php";
    curl_setopt($this->curl_handle, CURLOPT_URL, $this->url);
  }
  function tearDown() {
    // close our curl session when we're finished
    curl_close($this->curl_handle);
  }
}

// WebGoodAuthTestCase implements a test of successful authentication
class WebGoodAuthTestCase extends WebAuthTestCase {
  function __construct($name) {
    parent::__construct($name);
  }
  function testGoodAuth() {
    $user = 'george';
    // Consturct a user=NAME cookie
    $cookie = "user=$user;";
    // Set the cookie to be sent
    curl_setopt($this->curl_handle, CURLOPT_COOKIE, $cookie);
    // execute our query
    $ret = curl_exec($this->curl_handle);
    $this->assertRegExp("/<!-- crafted for $user -->/", $ret);
  }
}

// WebBadAuthTestCase implements a test of unsuccessful authentication
class WebBadAuthTestCase extends WebAuthTestCase {
  function __construct($name) {
    parent::__construct($name);
  }
  function testBadAuth() {
    // Don't pass a cookie
    curl_setopt($this->curl_handle, CURLOPT_COOKIE, $cookie);
// execute our query
    $ret = curl_exec($this->curl_handle);
    if(preg_match("/<!-- crafted for /", $ret)) {
      $this->fail();
    }
    else {
      $this->pass();
    }
  }
}

if(realpath($_SERVER['PHP_SELF']) == __FILE__) {
  require_once "PHPUnit/Framework/TestSuite.php";
  require_once "PHPUnit/TextUI/TestRunner.php";

  $suite = new PHPUnit_Framework_TestSuite('WebGoodAuthTestCase');
  $suite->addTestSuite("WebBadAuthTestCase");
  PHPUnit_TextUI_TestRunner::run($suite);
}
?>

